@@ -1,6 +1,6 @@
 /*
 	TECkit_Compile.c
-	Copyright (c) 2002-2011 SIL International.
+	Copyright (c) 2002-2014 SIL International.
 	
 	2004-03-12	updated to use v2.1 compiler
 				added -u option to force UTF8 mode
@@ -30,13 +30,13 @@ extern "C" {
 static
 void
 CALLBACK
-errFunc(void* userData, const char* msg, const char* param, UInt32 line)
+errFunc(void* /*userData*/, const char* msg, const char* param, UInt32 line)
 {
 	fprintf(stderr, "%s", msg);
 	if (param != 0)
 		fprintf(stderr, ": \"%s\"", param);
 	if (line != 0)
-		fprintf(stderr, " at line %lu", line);
+		fprintf(stderr, " at line %lu", (unsigned long)line);
 	fprintf(stderr, "\n");
 }
 
