@@ -1,5 +1,5 @@
 #define banner  \
-"hbf2gf (CJK ver. 4.8.3)" \
+"hbf2gf (CJK ver. 4.8.4)" \
  \
 
 #define TRUE 1
@@ -41,7 +41,7 @@
 #define GF_ID 131
 #define PRE 247 \
 
-#define header " hbf2gf output " \
+#define headerstring " hbf2gf output " \
 
 #define BOC 67
 #define BOC1 68
@@ -100,10 +100,10 @@
 #define VALID_SUBCODE 1 \
 
 /*4:*/
-#line 191 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 191 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*10:*/
-#line 408 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 408 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_CONFIG_H
 #include <c-auto.h> 
@@ -121,7 +121,7 @@
 
 
 /*:10*//*69:*/
-#line 2473 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2473 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 #include "kpathsea/kpathsea.h"
@@ -134,46 +134,46 @@
 #endif
 
 /*:69*/
-#line 192 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 192 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*11:*/
-#line 429 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 429 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_file(void);
 
 
 /*:11*//*13:*/
-#line 491 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 491 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_pre(void);
 
 
 /*:13*//*16:*/
-#line 579 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 579 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_data(void);
 
 
 /*:16*//*20:*/
-#line 690 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 690 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_post(void);
 
 
 /*:20*//*25:*/
-#line 834 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 834 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void fputl(long,FILE*);
 
 
 /*:25*//*29:*/
-#line 994 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 994 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void make_pixel_array(void);
 
 
 /*:29*//*36:*/
-#line 1222 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1222 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static
 #ifdef __GNUC__
@@ -183,7 +183,7 @@ void read_row(unsigned char*);
 
 
 /*:36*//*39:*/
-#line 1274 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1274 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static
 #ifdef __GNUC__
@@ -193,55 +193,55 @@ void write_row(unsigned char*);
 
 
 /*:39*//*41:*/
-#line 1329 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1329 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_coding(void);
 
 
 /*:41*//*45:*/
-#line 1490 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1490 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_pl(void);
 
 
 /*:45*//*47:*/
-#line 1587 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1587 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_ovp(void);
 
 
 /*:47*//*50:*/
-#line 1732 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1732 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_job(void);
 
 
 /*:50*//*54:*/
-#line 1981 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1981 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void read_config(void);
 
 
 /*:54*//*64:*/
-#line 2312 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2312 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static int fsearch(const char*);
 
 
 /*:64*//*67:*/
-#line 2451 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2451 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void config_error(const char*);
 
 
 /*:67*//*71:*/
-#line 2494 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2494 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static const char*TeX_search_version(void);
 
 
 /*:71*//*74:*/
-#line 2529 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2529 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 extern int setup_list(struct emtex_dir*,char*,const char*,unsigned);
@@ -251,17 +251,17 @@ static char*file_find(char*,struct emtex_dir*);
 
 
 /*:74*//*79:*/
-#line 2621 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2621 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static char*TeX_search_cfg_file(char*);
 static char*TeX_search_hbf_file(char*);
 
 
 /*:79*/
-#line 193 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 193 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*2:*/
-#line 127 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 127 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 int nmb_files= -1;
 int unicode= FALSE;
@@ -302,7 +302,7 @@ int end_of_file= FALSE;
 
 
 /*:2*//*15:*/
-#line 538 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 538 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 long char_adr[256];
 long*char_adr_p;
@@ -344,7 +344,7 @@ int dot_count;
 
 
 /*:15*//*19:*/
-#line 667 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 667 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 char coding[STRING_LENGTH+1];
 char comment[STRING_LENGTH+1];
@@ -363,7 +363,7 @@ double ppp_y;
 
 
 /*:19*//*27:*/
-#line 871 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 871 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 HBF_CHAR code;
 const unsigned char*bitmap;
@@ -386,13 +386,13 @@ long s_mag_x,s_mag_y,s_slant;
 
 
 /*:27*//*38:*/
-#line 1269 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1269 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 int threshold= 128;
 
 
 /*:38*//*49:*/
-#line 1721 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1721 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 char job_extension[EXTENSION_LENGTH+1];
 char rm_command[STRING_LENGTH+1];
@@ -404,13 +404,13 @@ int ofm_file= FALSE;
 
 
 /*:49*//*53:*/
-#line 1976 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1976 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 char Buffer[STRING_LENGTH+1];
 
 
 /*:53*//*58:*/
-#line 2094 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2094 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 int offset_x;
 int offset_y;
@@ -419,13 +419,13 @@ HBF_CHAR user_min_char;
 int have_min_char= FALSE;
 
 /*:58*//*60:*/
-#line 2251 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2251 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 HBF_CHAR min_char,max_char;
 
 
 /*:60*//*62:*/
-#line 2278 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2278 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 char b2_codes[256];
 unsigned char min_2_byte,max_2_byte;
@@ -433,7 +433,7 @@ int nmb_2_bytes= 0;
 
 
 /*:62*//*70:*/
-#line 2485 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2485 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_EMTEXDIR)
 char emtex_version_string[]= "emTeXdir";
@@ -443,7 +443,7 @@ char no_version_string[]= "no search library";
 
 
 /*:70*//*73:*/
-#line 2522 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2522 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 struct emtex_dir cfg_path,hbf_path;
@@ -451,7 +451,7 @@ struct emtex_dir cfg_path,hbf_path;
 
 
 /*:73*//*76:*/
-#line 2569 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2569 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 char name_buffer[FILE_NAME_LENGTH+1];
@@ -459,7 +459,7 @@ char name_buffer[FILE_NAME_LENGTH+1];
 
 
 /*:76*/
-#line 194 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 194 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 
@@ -467,7 +467,7 @@ int main(int argc,char*argv[])
 {char*p;
 
 /*78:*/
-#line 2594 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2594 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 kpse_set_program_name(argv[0],"hbf2gf");
@@ -488,16 +488,16 @@ exit(1);
 
 
 /*:78*/
-#line 200 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 200 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 /*7:*/
-#line 307 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 307 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 if(argc==2)
 {if(strcmp(argv[1],"--help")==0)
 /*6:*/
-#line 288 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 288 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {printf(USAGE);
 exit(0);
@@ -505,11 +505,11 @@ exit(0);
 
 
 /*:6*/
-#line 310 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 310 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 else if(strcmp(argv[1],"--version")==0)
 /*5:*/
-#line 261 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 261 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {printf("\n");
 printf(banner);
@@ -520,7 +520,7 @@ exit(0);
 
 
 /*:5*/
-#line 312 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 312 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 
@@ -558,7 +558,7 @@ exit(1);
 
 
 /*:7*/
-#line 202 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 202 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 if(!quiet)
@@ -587,7 +587,7 @@ read_config();
 
 if(mf_like)
 /*8:*/
-#line 352 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 352 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {if(unicode)
 file_number= (int)strtol(&argv[1][strlen(argv[1])-2],
@@ -615,11 +615,11 @@ y_scale= (double)x_resolution/y_scale;
 
 
 /*:8*/
-#line 229 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 229 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 /*28:*/
-#line 903 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 903 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {int col,offset;
 
@@ -702,11 +702,11 @@ s_slant= slant*SCALE;
 
 
 /*:28*/
-#line 231 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 231 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 /*9:*/
-#line 387 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 387 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {int j,max_numb;
 
@@ -728,7 +728,7 @@ nmb_files= j;
 
 
 /*:9*/
-#line 233 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 233 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 if(tfm_files)
@@ -746,7 +746,7 @@ return 0;
 
 
 /*:4*//*12:*/
-#line 437 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 437 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_file(void)
 {char output_file[FILE_NAME_LENGTH+1];
@@ -790,7 +790,7 @@ write_data();
 
 
 /*:12*//*14:*/
-#line 498 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 498 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_pre(void)
 {char out_s[40],s[20];
@@ -798,7 +798,7 @@ time_t secs_now;
 struct tm*time_now;
 
 
-strcpy(out_s,header);
+strcpy(out_s,headerstring);
 
 secs_now= time(NULL);
 time_now= localtime(&secs_now);
@@ -813,7 +813,7 @@ fputs(out_s,out);
 
 
 /*:14*//*17:*/
-#line 584 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 584 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_data(void)
 {dot_count= 0;
@@ -821,7 +821,7 @@ char_adr_p= char_adr;
 
 for(last_char= 0;(last_char<256)&&!end_of_file;last_char++)
 /*18:*/
-#line 609 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 609 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {if(dot_count++%10==0)
 if(pk_files&&!quiet)
@@ -865,13 +865,13 @@ fputc(EOC,out);
 
 
 /*:18*/
-#line 590 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 590 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:17*//*21:*/
-#line 695 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 695 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_post(void)
 {long special_adr;
@@ -899,7 +899,7 @@ tfm_width= (tfm_output_size_x+2*tfm_offset_x)*_2_20;
 
 
 /*22:*/
-#line 741 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 741 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 special_adr= ftell(out);
 
@@ -917,10 +917,10 @@ fputs(comment,out);
 
 
 /*:22*/
-#line 721 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 721 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*23:*/
-#line 770 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 770 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 post_adr= ftell(out);
 fputc(POST,out);
@@ -959,10 +959,10 @@ fputl(*char_adr_p++,out);
 
 
 /*:23*/
-#line 722 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 722 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*24:*/
-#line 821 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 821 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 fputc(POSTPOST,out);
 fputl(post_adr,out);
@@ -974,13 +974,13 @@ fputc(POSTPOST_ID,out);
 
 
 /*:24*/
-#line 723 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 723 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:21*//*26:*/
-#line 839 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 839 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void fputl(long num,FILE*f)
 {fputc(num>>24,f);
@@ -991,7 +991,7 @@ fputc(num,f);
 
 
 /*:26*//*30:*/
-#line 999 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 999 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void make_pixel_array(void)
 {unsigned char*prP;
@@ -1029,7 +1029,7 @@ if(!bitmap)
 empty_char= TRUE;
 else
 /*31:*/
-#line 1058 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1058 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {if(pk_output_size_y==input_size_y)
 temp_prP= prP;
@@ -1037,7 +1037,7 @@ temp_prP= prP;
 curr_row= input_size_y-1;
 for(row= 0;row<pk_output_size_y;++row)
 {/*32:*/
-#line 1072 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1072 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 if(pk_output_size_y==input_size_y)
 
@@ -1059,7 +1059,7 @@ need_to_read_row= 1;
 }
 
 /*33:*/
-#line 1099 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1099 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 if(need_to_read_row)
 if(rows_read<input_size_y)
@@ -1091,16 +1091,16 @@ frac_row_to_fill= SCALE;
 
 
 /*:33*/
-#line 1092 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1092 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:32*/
-#line 1064 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1064 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*34:*/
-#line 1140 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1140 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 if(pk_width==input_size_x&&s_slant==0)
 
@@ -1155,7 +1155,7 @@ frac_col_to_fill-= frac_col_left;
 }
 
 /*35:*/
-#line 1198 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1198 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 if(frac_col_to_fill> 0)
 {--xP;
@@ -1175,20 +1175,20 @@ write_row(new_prP);
 
 
 /*:35*/
-#line 1193 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1193 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:34*/
-#line 1066 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1066 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 }
 
 
 /*:31*/
-#line 1035 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1035 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 }
 }
@@ -1212,7 +1212,7 @@ goto again;
 
 
 /*:30*//*37:*/
-#line 1231 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1231 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static
 #ifdef __GNUC__
@@ -1248,7 +1248,7 @@ bitshift= 7;
 
 
 /*:37*//*40:*/
-#line 1283 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1283 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static
 #ifdef __GNUC__
@@ -1265,7 +1265,7 @@ for(col= 0,xP= pixelrow;col<pk_output_size_x;++col,++xP)
 
 
 /*:40*//*42:*/
-#line 1337 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1337 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_coding(void)
 {register int count,skip;
@@ -1282,7 +1282,7 @@ goto start;
 
 while(y<pk_output_size_y)
 {/*43:*/
-#line 1361 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1361 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 count= 0;
 x= 0;
@@ -1351,11 +1351,11 @@ continue;
 
 
 /*:43*/
-#line 1352 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1352 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 start:
 /*44:*/
-#line 1429 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1429 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 while(x<pk_output_size_x)
 {if(*cp==paint)
@@ -1396,7 +1396,7 @@ paint= WHITE;
 
 
 /*:44*/
-#line 1354 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1354 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 y++;
 }
@@ -1404,7 +1404,7 @@ y++;
 
 
 /*:42*//*46:*/
-#line 1495 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1495 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_pl(void)
 {int i,pos;
@@ -1494,7 +1494,7 @@ fclose(out);
 
 
 /*:46*//*48:*/
-#line 1592 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1592 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_ovp(void)
 {int c,i,nmb_subfonts,remainder,count,pos;
@@ -1609,7 +1609,7 @@ fclose(out);
 
 
 /*:48*//*51:*/
-#line 1737 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1737 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void write_job(void)
 {FILE*out;
@@ -1695,7 +1695,7 @@ fclose(out);
 
 
 /*:51*//*55:*/
-#line 1989 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1989 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void read_config(void)
 {HBF_BBOX*boxp;
@@ -1703,7 +1703,7 @@ char*real_config_file;
 
 
 /*56:*/
-#line 2041 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2041 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {int i,lastext= -1;
 
@@ -1721,7 +1721,7 @@ strcat(config_file,".cfg");
 
 
 /*:56*/
-#line 1995 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 1995 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 real_config_file= TeX_search_cfg_file(config_file);
@@ -1756,7 +1756,7 @@ exit(0);
 }
 
 /*57:*/
-#line 2058 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2058 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {char hbf_header[STRING_LENGTH+1];
 char*real_hbf_header;
@@ -1793,10 +1793,10 @@ strcpy(output_name,Buffer);
 
 
 /*:57*/
-#line 2028 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2028 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*59:*/
-#line 2102 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2102 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {if(fsearch("nmb_files"))
 nmb_files= atoi(Buffer);
@@ -1938,11 +1938,11 @@ job_extension[EXTENSION_LENGTH]= '\0';
 
 
 /*:59*/
-#line 2029 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2029 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 /*61:*/
-#line 2256 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2256 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {const void*cp;
 HBF_CHAR dummy;
@@ -1957,10 +1957,10 @@ min_char= user_min_char;
 
 
 /*:61*/
-#line 2031 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2031 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 /*63:*/
-#line 2285 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2285 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {const void*b2r;
 unsigned char dummy;
@@ -1983,7 +1983,7 @@ nmb_2_bytes++;
 
 
 /*:63*/
-#line 2032 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2032 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 
 fclose(config);
@@ -1991,7 +1991,7 @@ fclose(config);
 
 
 /*:55*//*65:*/
-#line 2317 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2317 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static int fsearch(const char*search_string)
 {char*P,p;
@@ -2047,7 +2047,7 @@ Ch= fgetc(config);
 
 if(*temp_buffer)
 /*66:*/
-#line 2396 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2396 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 {P= temp_buffer;
 Buf_p= Buffer;
@@ -2100,7 +2100,7 @@ count--;
 
 
 /*:66*/
-#line 2371 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2371 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 else
 *Buffer= '\0';
@@ -2110,7 +2110,7 @@ return(*Buffer)?1:0;
 
 
 /*:65*//*68:*/
-#line 2456 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2456 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static void config_error(const char*message)
 {fprintf(stderr,"Couldn't find `%s' entry in configuration file\n",
@@ -2121,7 +2121,7 @@ exit(1);
 
 
 /*:68*//*72:*/
-#line 2499 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2499 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 static const char*TeX_search_version(void)
 {
@@ -2143,7 +2143,7 @@ return no_version_string;
 
 
 /*:72*//*75:*/
-#line 2541 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2541 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 static int dir_setup(ed,env,dir,flags)
@@ -2172,7 +2172,7 @@ return TRUE;
 
 
 /*:75*//*77:*/
-#line 2576 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2576 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 static char*file_find(name,list)
@@ -2188,7 +2188,7 @@ return NULL;
 
 
 /*:77*//*80:*/
-#line 2627 "./cjkutils-4.8.3/hbf2gf/hbf2gf.w"
+#line 2627 "./cjkutils-4.8.4/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
 static char*TeX_search_cfg_file(char*name)
