@@ -106,11 +106,6 @@ pdf_font_make_uniqueTag (char *tag)
 
 struct pdf_font
 {
-#ifdef XETEX
-  FT_Face  ft_face;
-  unsigned short *ft_to_gid;
-#endif
-
   char    *ident;
   int      subtype;
 
@@ -153,10 +148,6 @@ pdf_init_font_struct (pdf_font *font)
 {
   ASSERT(font);
 
-#ifdef XETEX
-  font->ft_face  = NULL;
-#endif
-
   font->ident    = NULL;
   font->map_name = NULL;
   font->subtype  = -1;
@@ -647,7 +638,7 @@ pdf_font_findresource (const char *tex_name,
      */
     int  type0_id, found = 0;
 
-    type0_id = pdf_font_findfont0(mrec->font_name, cmap_id, &mrec->opt);
+    type0_id = Type0Font_cache_find(mrec->font_name, cmap_id, &mrec->opt);
     if (type0_id < 0) {
       return -1;
     }
@@ -676,11 +667,6 @@ pdf_font_findresource (const char *tex_name,
       font    = GET_FONT(font_id);
       pdf_init_font_struct(font);
 
-#ifdef XETEX
-      font->ft_to_gid = Type0Font_get_ft_to_gid(type0_id);
-      font->ft_face = mrec->opt.ft_face;
-#endif
-
       font->font_id     = type0_id;
       font->subtype     = PDF_FONT_FONTTYPE_TYPE0;
       font->encoding_id = cmap_id;
@@ -758,10 +744,6 @@ pdf_font_findresource (const char *tex_name,
 
       pdf_init_font_struct(font);
 
-#ifdef XETEX
-      font->ft_face = mrec ? mrec->opt.ft_face : NULL;
-#endif
-
       font->point_size  = font_scale;
       font->encoding_id = encoding_id;
       font->ident       = NEW(strlen(fontname) + 1, char);
@@ -805,28 +787,6 @@ pdf_font_is_in_use (pdf_font *font)
   return ((font->reference) ? 1 : 0);
 }
 
-#ifdef XETEX
-FT_Face
-pdf_font_get_ft_face (pdf_font *font)
-{
-  ASSERT(font);
-
-  return font->ft_face;
-}
-
-unsigned short *
-pdf_get_font_ft_to_gid (int font_id)
-{
-  pdf_font *font;
-
-  CHECK_ID(font_id);
-
-  font = GET_FONT(font_id);
-
-  return font->ft_to_gid;
-}
-#endif
-
 int
 pdf_font_get_index (pdf_font *font)
 {
