@@ -1,5 +1,5 @@
 /* This is extractbb, a bounding box extraction program.
-    Copyright (C) 2008-2014 by Jin-Hwan Cho and Matthias Franz
+    Copyright (C) 2008-2015 by Jin-Hwan Cho and Matthias Franz
     and the dvipdfmx project team.
 
     This program is free software; you can redistribute it and/or modify
@@ -43,11 +43,12 @@
 
 #define XBB_PROGRAM "extractbb"
 
+static long Include_Page = 1;
+
 static void show_version(void)
 {
   fprintf (stdout, "\nThis is " XBB_PROGRAM " Version " VERSION "\n");
-  fprintf (stdout, "A bounding box extraction utility from PDF, PNG, and JPEG.\n");
-  fprintf (stdout, "\nCopyright (C) 2008-2014 by Jin-Hwan Cho and Matthias Franz\n");
+  fprintf (stdout, "\nCopyright (C) 2008-2015 by Jin-Hwan Cho and Matthias Franz\n");
   fprintf (stdout, "\nThis is free software; you can redistribute it and/or modify\n");
   fprintf (stdout, "it under the terms of the GNU General Public License as published by\n");
   fprintf (stdout, "the Free Software Foundation; either version 2 of the License, or\n");
@@ -56,11 +57,13 @@ static void show_version(void)
 
 static void show_usage(void)
 {
-  fprintf (stdout, "\nUsage: " XBB_PROGRAM " [-q|-v] [-O] [-m|-x] file...\n");
+  fprintf (stdout, "\nUsage: " XBB_PROGRAM " [-p page] [-q|-v] [-O] [-m|-x] FILE...\n");
   fprintf (stdout, "       " XBB_PROGRAM " --help|--version\n");
+  fprintf (stdout, "Extract bounding box from PDF, PNG, or JPEG file; default output below.\n");
   fprintf (stdout, "\nOptions:\n");
   fprintf (stdout, "  -h | --help\tShow this help message and exit\n");
   fprintf (stdout, "  --version\tOutput version information and exit\n");
+  fprintf (stdout, "  -p page\tSpecify a PDF page to extract bounding box\n");
   fprintf (stdout, "  -q\t\tBe quiet\n");
   fprintf (stdout, "  -v\t\tBe verbose\n");
   fprintf (stdout, "  -O\t\tWrite output to stdout\n");
@@ -234,7 +237,7 @@ static void do_pdf (FILE *fp, char *filename)
 {
   pdf_obj *page;
   pdf_file *pf;
-  long page_no = 1;
+  long page_no = Include_Page;
   long count;
   pdf_rect bbox;
 
@@ -293,12 +296,22 @@ int extractbb (int argc, char *argv[])
       case 'x':
         compat_mode = 0;
         break;
+      case 'q':
+        verbose = 0;
+        break;
       case 'v':
         verbose = 1;
         break;
       case 'h':
         show_usage();
         exit (0);
+      case 'p':
+        argc--;
+        argv++;
+        Include_Page = atol (argv[0]);
+        if (Include_Page == 0)
+          Include_Page = 1;
+        break;
       default:
         fprintf (stderr, "Unknown option in \"%s\"", argv[0]);
         usage();
