@@ -479,7 +479,7 @@ static float t1_scan_num(char *p, char **r)
         pdftex_fail("a number expected: `%s'", t1_line_array);
     }
     if (r != NULL) {
-        for (; isdigit(*p) || *p == '.' ||
+        for (; isdigit((unsigned char)*p) || *p == '.' ||
              *p == 'e' || *p == 'E' || *p == '+' || *p == '-'; p++);
         *r = p;
     }
@@ -1167,7 +1167,9 @@ static void t1_subset_ascii_part(void)
     t1_getline();
     while (!t1_prefix("/Encoding")) {
         t1_scan_param();
-        t1_putline();
+        if (!(t1_prefix("/UniqueID")
+              && !strncmp(t1_line_array + strlen(t1_line_array) -4, "def", 3)))
+            t1_putline();
         t1_getline();
     }
     if (is_reencoded(fm_cur))
@@ -1327,7 +1329,7 @@ static void t1_flush_cs(boolean is_subr)
     t1_line_ptr = t1_line_array;
     for (p = start_line; p - start_line < size_pos;)
         *t1_line_ptr++ = *p++;
-    while (isdigit(*p))
+    while (isdigit((unsigned char)*p))
         p++;
     sprintf(t1_line_ptr, "%u", count);
     strcat(t1_line_ptr, p);
