@@ -2,7 +2,7 @@
 ** DVIReader.cpp                                                        **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -53,8 +53,8 @@ DVIReader::DVIReader (istream &is, DVIActions *a) : BasicDVIReader(is), _actions
 	_currPageNum = 0;
 	_pagePos = 0;
 	_mag = 1;
-	collectBopOffsets();
 	executePreamble();
+	collectBopOffsets();
 	executePostamble();
 }
 
@@ -149,16 +149,16 @@ static void to_postamble (StreamReader &reader) {
 	if (!reader.isStreamValid())
 		throw DVIException("invalid DVI file");
 
-	reader.seek(-1, ios_base::end);     // stream pointer to last byte
+	reader.seek(-1, ios::end);          // stream pointer to last byte
 	int count=0;
 	while (reader.peek() == 223) {
-		reader.seek(-1, ios_base::cur);  // skip fill bytes
+		reader.seek(-1, ios::cur);       // skip fill bytes
 		count++;
 	}
 	if (count < 4)  // the standard requires at least 4 trailing fill bytes
 		throw DVIException("missing fill bytes at end of file");
 
-	reader.seek(-4, ios_base::cur);     // now on first byte of q (pointer to begin of postamble)
+	reader.seek(-4, ios::cur);          // now on first byte of q (pointer to begin of postamble)
 	UInt32 q = reader.readUnsigned(4);  // pointer to begin of postamble
 	reader.seek(q);                     // now on begin of postamble
 }
@@ -623,7 +623,7 @@ void DVIReader::cmdXFontDef (int) {
 		// all color specials should be ignored, i.e. glyphs of a non-black fonts have a fixed color
 		// that can't be changed by color specials.
 		UInt32 rgba = readUnsigned(4);
-		color.set(UInt8(rgba >> 24), UInt8((rgba >> 16) & 0xff), UInt8((rgba >> 8) & 0xff));
+		color.setRGB(UInt8(rgba >> 24), UInt8((rgba >> 16) & 0xff), UInt8((rgba >> 8) & 0xff));
 	}
 	if (flags & 0x1000)   // extend?
 		style.extend = _dvi2bp*readSigned(4);
