@@ -2,7 +2,7 @@
 ** FontCache.cpp                                                        **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -338,7 +338,7 @@ bool FontCache::fontinfo (std::istream &is, FontInfo &info) {
 					}
 					info.numbytes += bc+1; // command length + command
 					info.numcmds++;
-					is.seekg(bc, ios_base::cur);
+					is.seekg(bc, ios::cur);
 				}
 				info.numbytes += 6; // number of path commands + char code
 			}
