@@ -2,7 +2,7 @@
 ** GFGlyphTracer.cpp                                                    **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -51,19 +51,19 @@ void GFGlyphTracer::reset (string &fname, double upp) {
 
 
 bool GFGlyphTracer::executeChar (UInt8 c) {
-	if (_glyph) {
-		if (_callback)
-			_callback->beginChar(c);
-		bool ok = GFTracer::executeChar(c);
-		if (_callback) {
-			if (ok)
-				_callback->endChar(c);
-			else
-				_callback->emptyChar(c);
-			return ok;
-		}
+	if (!_glyph)
+		return false;
+
+	if (_callback)
+		_callback->beginChar(c);
+	bool ok = GFTracer::executeChar(c);
+	if (_callback) {
+		if (ok)
+			_callback->endChar(c);
+		else
+			_callback->emptyChar(c);
 	}
-	return false;
+	return ok;
 }
 
 
