@@ -2,7 +2,7 @@
 ** PsSpecialHandler.h                                                   **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -38,6 +38,8 @@ class XMLElementNode;
 class PsSpecialHandler : public SpecialHandler, public DVIEndPageListener, protected PSActions
 {
 	typedef GraphicPath<double> Path;
+	typedef std::vector<double>::const_iterator DoubleVecIt;
+	typedef Color::ColorSpace ColorSpace;
 
 	class ClippingStack
 	{
@@ -81,13 +83,20 @@ class PsSpecialHandler : public SpecialHandler, public DVIEndPageListener, prote
 
 	public:
 		static bool COMPUTE_CLIPPATHS_INTERSECTIONS;
+		static bool SHADING_SEGMENT_OVERLAP;
+		static int SHADING_SEGMENT_SIZE;
+		static double SHADING_SIMPLIFY_DELTA;
 
 	protected:
 		void initialize ();
 		void moveToDVIPos ();
+		void executeAndSync (std::istream &is, bool updatePos);
 		void processHeaderFile (const char *fname);
 		void psfile (const std::string &fname, const std::map<std::string,std::string> &attr);
 		void dviEndPage (unsigned pageno);
+		void clip (Path &path, bool evenodd);
+		void processSequentialPatchMesh (int shadingTypeID, ColorSpace cspace, VectorIterator<double> &it);
+		void processLatticeTriangularPatchMesh (ColorSpace colorSpace, VectorIterator<double> &it);
 
 		/// scale given value by current PS scale factors
 		double scale (double v) const {return v*(_sx*_cos*_cos + _sy*(1-_cos*_cos));}
@@ -127,6 +136,7 @@ class PsSpecialHandler : public SpecialHandler, public DVIEndPageListener, prote
 		void setopacityalpha (std::vector<double> &p){_opacityalpha = p[0];}
 		void setpattern (std::vector<double> &p);
 		void setrgbcolor (std::vector<double> &rgb);
+		void shfill (std::vector<double> &p);
 		void stroke (std::vector<double> &p);
 		void translate (std::vector<double> &p);
 		void executed ();
@@ -141,6 +151,7 @@ class PsSpecialHandler : public SpecialHandler, public DVIEndPageListener, prote
 		std::string _headerCode;    ///< collected literal PS header code
 		Path _path;
 		DPair _currentpoint;        ///< current PS position in bp units
+		Color _currentcolor;        ///< current stroke/fill color
 		double _sx, _sy;            ///< horizontal and vertical scale factors retrieved by operator "applyscalevals"
 		double _cos;                ///< cosine of angle between (1,0) and transform(1,0)
 		double _linewidth;          ///< current linewidth
