@@ -2,7 +2,7 @@
 ** dvisvgm.cpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -20,9 +20,7 @@
 
 #include <config.h>
 #include <clipper.hpp>
-#include <cmath>
 #include <fstream>
-#include <iomanip>
 #include <iostream>
 #include <sstream>
 #include <string>
@@ -47,7 +45,7 @@
 #include "PsSpecialHandler.h"
 #include "SignalHandler.h"
 #include "SpecialManager.h"
-#include "SVGOutputBase.h"
+#include "SVGOutput.h"
 #include "System.h"
 
 #ifdef __MSVC__
@@ -60,101 +58,13 @@ extern "C" {
 
 using namespace std;
 
-class SVGOutput : public SVGOutputBase
-{
-	public:
-		SVGOutput (const char *base=0, string pattern="", int zip_level=0)
-			: _path(base ? base : ""),
-			_pattern(pattern),
-			_stdout(base == 0),
-			_zipLevel(zip_level),
-			_page(-1),
-			_os(0) {}
-
-
-		~SVGOutput () {
-			delete _os;
-		}
-
-
-		/** Returns an output stream for the given page.
-		 *  @param[in] page number of current page
-		 *  @param[in] numPages total number of pages in the DVI file
-		 *  @return output stream for the given page */
-		ostream& getPageStream (int page, int numPages) const {
-			string fname = filename(page, numPages);
-			if (fname.empty()) {
-				delete _os;
-				_os = 0;
-				return cout;
-			}
-			if (page == _page)
-				return *_os;
-
-			_page = page;
-			delete _os;
-
-			if (_zipLevel > 0)
-				_os = new ogzstream(fname.c_str(), _zipLevel);
-			else
-				_os = new ofstream(fname.c_str());
-			if (!_os || !*_os) {
-				delete _os;
-				_os = 0;
-				throw MessageException("can't open file "+fname+" for writing");
-			}
-			return *_os;
-		}
-
-
-		/** Returns the name of the SVG file containing the given page.
-		 *  @param[in] page number of current page
-		 *  @param[in] numPages total number of pages */
-		string filename (int page, int numPages) const {
-			if (_stdout)
-				return "";
-			string fname = _pattern;
-			if (fname.empty())
-				fname = numPages > 1 ? "%f-%p" : "%f";
-			else if (numPages > 1 && fname.find("%p") == string::npos)
-				fname += FileSystem::isDirectory(fname.c_str()) ? "/%f-%p" : "-%p";
-
-			// replace pattern variables by their actual values
-			// %f: basename of the DVI file
-			// %p: current page number
-			ostringstream oss;
-			oss << setfill('0') << setw(max(2, int(1+log10((double)numPages)))) << page;
-			size_t pos=0;
-			while ((pos = fname.find('%', pos)) != string::npos && pos < fname.length()-1) {
-				switch (fname[pos+1]) {
-					case 'f': fname.replace(pos, 2, _path.basename());  pos += _path.basename().length(); break;
-					case 'p': fname.replace(pos, 2, oss.str()); pos += oss.str().length(); break;
-					default : ++pos;
-				}
-			}
-			FilePath outpath(fname, true);
-			if (outpath.suffix().empty())
-				outpath.suffix(_zipLevel > 0 ? "svgz" : "svg");
-			string apath = outpath.absolute();
-			string rpath = outpath.relative();
-			return apath.length() < rpath.length() ? apath : rpath;
-		}
-
-	private:
-		FilePath _path;
-		string _pattern;
-		bool _stdout;
-		int _zipLevel;
-		mutable int _page; // number of current page being written
-		mutable ostream *_os;
-};
 
 ////////////////////////////////////////////////////////////////////////////////
 
 static void show_help (const CommandLine &cmd) {
 	cout << PACKAGE_STRING "\n\n";
 	cmd.help(cmd.help_arg());
-	cout << "\nCopyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de> \n\n";
+	cout << "\nCopyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de> \n\n";
 }
 
 
@@ -344,29 +254,33 @@ int main (int argc, char *argv[]) {
 
 	if (args.progress_given()) {
 		DVIReader::COMPUTE_PROGRESS = args.progress_given();
-		DVIToSVGActions::PROGRESSBAR_DELAY = args.progress_arg();
+		SpecialActions::PROGRESSBAR_DELAY = args.progress_arg();
 	}
 	SVGTree::CREATE_STYLE = !args.no_styles_given();
 	SVGTree::USE_FONTS = !args.no_fonts_given();
 	SVGTree::CREATE_USE_ELEMENTS = args.no_fonts_arg() < 1;
 	SVGTree::ZOOM_FACTOR = args.zoom_arg();
 	SVGTree::RELATIVE_PATH_CMDS = args.relative_given();
+	SVGTree::MERGE_CHARS = !args.no_merge_given();
 	DVIToSVG::TRACE_MODE = args.trace_all_given() ? (args.trace_all_arg() ? 'a' : 'm') : 0;
 	Message::LEVEL = args.verbosity_arg();
 	PhysicalFont::EXACT_BBOX = args.exact_given();
 	PhysicalFont::KEEP_TEMP_FILES = args.keep_given();
-	PhysicalFont::METAFONT_MAG = args.mag_arg();
-	PsSpecialHandler::COMPUTE_CLIPPATHS_INTERSECTIONS = args.clipjoin_given();
+	PhysicalFont::METAFONT_MAG = max(1.0, args.mag_arg());
 	XMLString::DECIMAL_PLACES = max(0, min(6, args.precision_arg()));
 	if (!HtmlSpecialHandler::setLinkMarker(args.linkmark_arg()))
 		Message::wstream(true) << "invalid argument '"+args.linkmark_arg()+"' supplied for option --linkmark\n";
 	double start_time = System::time();
 	bool eps_given=false;
-#if defined(HAVE_LIBGS) || !defined(DISABLE_GS)
+#ifndef DISABLE_GS
 	eps_given = args.eps_given();
+	PsSpecialHandler::COMPUTE_CLIPPATHS_INTERSECTIONS = args.clipjoin_given();
+	PsSpecialHandler::SHADING_SEGMENT_OVERLAP = args.grad_overlap_given();
+	PsSpecialHandler::SHADING_SEGMENT_SIZE = max(1, args.grad_segments_arg());
+	PsSpecialHandler::SHADING_SIMPLIFY_DELTA = args.grad_simplify_arg();
 #endif
 	string inputfile = ensure_suffix(args.file(0), eps_given);
-	ifstream ifs(inputfile.c_str(), ios_base::binary|ios_base::in);
+	ifstream ifs(inputfile.c_str(), ios::binary|ios::in);
 	if (!ifs) {
 		Message::estream(true) << "can't open file '" << inputfile << "' for reading\n";
 		return 0;
@@ -374,7 +288,7 @@ int main (int argc, char *argv[]) {
 	try {
 		SVGOutput out(args.stdout_given() ? 0 : inputfile.c_str(), args.output_arg(), args.zip_given() ? args.zip_arg() : 0);
 		SignalHandler::instance().start();
-#if defined(HAVE_LIBGS) || !defined(DISABLE_GS)
+#ifndef DISABLE_GS
 		if (args.eps_given()) {
 			EPSToSVG eps2svg(inputfile, out);
 			eps2svg.convert();
@@ -408,6 +322,7 @@ int main (int argc, char *argv[]) {
 		Message::estream() << "\nPostScript error: " << e.what() << '\n';
 	}
 	catch (SignalException &e) {
+		Message::wstream().clearline();
 		Message::wstream(true) << "execution interrupted by user\n";
 	}
 	catch (MessageException &e) {
