@@ -2,7 +2,7 @@
 
 /* cff.{cc,hh} -- Compact Font Format fonts
  *
- * Copyright (c) 1998-2012 Eddie Kohler
+ * Copyright (c) 1998-2014 Eddie Kohler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -28,7 +28,7 @@
 #include <efont/t1unparser.hh>
 
 #ifndef static_assert
-#define static_assert(c) switch (c) case 0: case (c):
+#define static_assert(c, msg) switch ((int) (c)) case 0: case (c):
 #endif
 
 namespace Efont {
@@ -332,7 +332,8 @@ default_dict()
     static Cff *cff;
     static Cff::Font *cfffont;
     if (!cfffont) {
-	cff = new Cff(String::make_stable((const char *) default_dict_cff_data, sizeof(default_dict_cff_data)), ErrorHandler::default_handler());
+	cff = new Cff(String::make_stable((const char *) default_dict_cff_data, sizeof(default_dict_cff_data)),
+                      0, ErrorHandler::default_handler());
 	cfffont = (Cff::Font *) cff->font();
     }
     return cfffont->top_dict();
@@ -342,13 +343,16 @@ default_dict()
 #define POS_GT(pos1, pos2)	((unsigned)(pos1) > (unsigned)(pos2))
 
 
-Cff::Cff(const String &s, ErrorHandler *errh)
+Cff::Cff(const String& s, unsigned units_per_em, ErrorHandler* errh)
     : _data_string(s), _data(reinterpret_cast<const uint8_t *>(_data_string.data())), _len(_data_string.length()),
-      _strings_map(-2)
+      _strings_map(-2), _units_per_em(units_per_em)
 {
-    static_assert((sizeof(standard_strings) / sizeof(standard_strings[0])) == NSTANDARD_STRINGS);
-    static_assert((sizeof(standard_encoding) / sizeof(standard_encoding[0])) == 256);
-    static_assert((sizeof(expert_encoding) / sizeof(expert_encoding[0])) == 256);
+    static_assert((sizeof(standard_strings) / sizeof(standard_strings[0])) == NSTANDARD_STRINGS,
+                  "NSTANDARD_STRINGS defined incorrectly");
+    static_assert((sizeof(standard_encoding) / sizeof(standard_encoding[0])) == 256,
+                  "standard_encoding has wrong size");
+    static_assert((sizeof(expert_encoding) / sizeof(expert_encoding[0])) == 256,
+                  "expert_encoding has wrong size");
     _error = parse_header(errh ? errh : ErrorHandler::silent_handler());
 }
 
@@ -372,7 +376,7 @@ Cff::parse_header(ErrorHandler *errh)
     if (_len == 0)
 	return errh->error("not a PostScript-flavored OpenType font"), -EFAULT;
     if (_len < HEADER_SIZE)
-	return errh->error("CFF file too small for header (have %d, want %d)", _len, HEADER_SIZE), -EFAULT;
+	return errh->error("CFF file corrupted (too small)"), -EFAULT;
     if (_data[0] != 1)		// major version number
 	return errh->error("bad major version number %d", _data[0]), -ERANGE;
     int hdrSize = _data[2], offSize = _data[3];
@@ -541,7 +545,7 @@ Cff::font(PermString font_name, ErrorHandler *errh)
     if (!font_name)
 	errh->error("no fonts in CFF");
     else
-	errh->error("font '%s' not found", font_name.c_str());
+	errh->error("font %<%s%> not found", font_name.c_str());
     return 0;
 }
 
@@ -606,7 +610,7 @@ Cff::Charset::assign(const Cff *cff, int pos, int nglyphs, int max_sid, ErrorHan
     if (_error >= 0)
 	for (int g = 0; g < _sids.size(); g++) {
 	    if (_gids[_sids[g]] >= 0) {
-		errh->error("glyph '%s' in charset twice", cff->sid_permstring(_sids[g]).c_str());
+		errh->error("glyph %<%s%> in charset twice", cff->sid_permstring(_sids[g]).c_str());
 		_error = -EEXIST;
 	    }
 	    _gids[_sids[g]] = g;
@@ -1006,7 +1010,7 @@ Cff::Dict::check(bool is_private, ErrorHandler *errh, const char *dict_name) con
 	if (op >= operators_used.size())
 	    operators_used.resize(op + 1, 0);
 	if (operators_used[op] && (type & tTypeMask) != tNone)
-	    errh->error("%s: operator '%s' specified twice", dict_name, operator_names[op]);
+	    errh->error("%s: operator %<%s%> specified twice", dict_name, operator_names[op]);
 	operators_used[op]++;
 
 	// check data
@@ -1014,9 +1018,9 @@ Cff::Dict::check(bool is_private, ErrorHandler *errh, const char *dict_name) con
 
 	  case tNone:
 	    if (op >= 32)
-		errh->warning("%s: unknown operator '12 %d'", dict_name, op - 32);
+		errh->warning("%s: unknown operator %<12 %d%>", dict_name, op - 32);
 	    else
-		errh->warning("%s: unknown operator '%d'", dict_name, op);
+		errh->warning("%s: unknown operator %<%d%>", dict_name, op);
 	    continue;
 
 	  case tSID:
@@ -1033,7 +1037,7 @@ Cff::Dict::check(bool is_private, ErrorHandler *errh, const char *dict_name) con
 	    if (arity != 1)
 		goto bad_data;
 	    else if (num != 0 && num != 1)
-		errh->warning("%s: data for Boolean operator '%s' not 0 or 1", dict_name, operator_names[op]);
+		errh->warning("%s: data for Boolean operator %<%s%> not 0 or 1", dict_name, operator_names[op]);
 	    break;
 
 	  case tNumber:
@@ -1073,12 +1077,12 @@ Cff::Dict::check(bool is_private, ErrorHandler *errh, const char *dict_name) con
 
 	// check dict location
 	if (((type & tPrivate) != 0) != is_private)
-	    errh->warning("%s: operator '%s' in wrong DICT", dict_name, operator_names[op]);
+	    errh->warning("%s: operator %<%s%> in wrong DICT", dict_name, operator_names[op]);
 
 	continue;
 
       bad_data:
-	errh->error("%s: bad data for operator '%s'", dict_name, operator_names[op]);
+	errh->error("%s: bad data for operator %<%s%>", dict_name, operator_names[op]);
     }
 
     return (errh->nerrors() != before_nerrors ? -1 : 0);
@@ -1200,8 +1204,8 @@ handle_private(Cff *cff, const Cff::Dict &top_dict, Cff::Dict &private_dict,
 }
 
 
-Cff::FontParent::FontParent(Cff *cff)
-    : _cff(cff), _error(-1)
+Cff::FontParent::FontParent(Cff* cff)
+    : CharstringProgram(cff->units_per_em()), _cff(cff), _error(-1)
 {
 }
 
