@@ -1,6 +1,6 @@
 /* secondary.{cc,hh} -- code for generating fake glyphs
  *
- * Copyright (c) 2003-2012 Eddie Kohler
+ * Copyright (c) 2003-2014 Eddie Kohler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -89,13 +89,13 @@ enum {
 FontInfo::FontInfo(const Efont::OpenType::Font *otf_, ErrorHandler *errh)
     : otf(otf_), cmap(0), cff_file(0), cff(0), post(0), name(0), _nglyphs(-1),
       _got_glyph_names(false), _ttb_program(0), _override_is_fixed_pitch(false),
-      _override_italic_angle(false)
+      _override_italic_angle(false), _override_x_height(x_height_auto)
 {
     cmap = new Efont::OpenType::Cmap(otf->table("cmap"), errh);
     assert(cmap->ok());
 
     if (String cff_string = otf->table("CFF")) {
-	cff_file = new Efont::Cff(cff_string, errh);
+	cff_file = new Efont::Cff(cff_string, otf->units_per_em(), errh);
 	if (!cff_file->ok())
 	    return;
 	Efont::Cff::FontParent *fp = cff_file->font(PermString(), errh);
@@ -219,6 +219,34 @@ FontInfo::italic_angle() const
 	return post->italic_angle();
 }
 
+double FontInfo::x_height(const Transform& font_xform) const {
+    if (_override_x_height == x_height_explicit)
+        return _x_height;
+    double x1 = -1, x2 = -1;
+    if (_override_x_height != x_height_os2)
+	// XXX what if 'x', 'm', 'z' were subject to substitution?
+	x1 = char_one_bound(*this, font_xform, 3, false, units_per_em(),
+                            (int) 'x', (int) 'm', (int) 'z', 0);
+    if (_override_x_height != x_height_x)
+        try {
+            Efont::OpenType::Os2 os2(otf->table("OS/2"));
+            x2 = (Point(0, os2.x_height()) * font_xform).y;
+        } catch (Efont::OpenType::Bounds) {
+        }
+    static bool warned = false;
+    if (_override_x_height == x_height_auto && x1 >= 0 && x2 >= 0
+        && fabs(x1 - x2) > units_per_em() / 100.) {
+        if (!warned) {
+            ErrorHandler* errh = ErrorHandler::default_handler();
+            errh->warning("font x-height and height of %<x%> differ by %d%%", (int) (fabs(x1 - x2) * 100 / units_per_em()));
+            errh->message("(The height of %<x%> is usually more reliable than the x-height, so I%,m\nusing that. Or try --use-x-height or --no-use-x-height.)\n");
+            warned = true;
+        }
+        return x1;
+    } else
+        return x2 >= 0 ? x2 : x1;
+}
+
 
 /* */
 
@@ -271,12 +299,12 @@ T1Secondary::T1Secondary(const FontInfo &finfo, const String &font_name,
 			 const String &otf_file_name)
     : _finfo(finfo), _font_name(font_name), _otf_file_name(otf_file_name),
       _units_per_em(finfo.units_per_em()),
-      _xheight(font_x_height(finfo, Transform())),
+      _xheight((int) ceil(finfo.x_height(Transform()))),
       _spacewidth(_units_per_em)
 {
-    int bounds[4], width;
+    double bounds[4], width;
     if (char_bounds(bounds, width, finfo, Transform(), ' '))
-	_spacewidth = width;
+	_spacewidth = (int) ceil(width);
 }
 
 int
@@ -452,13 +480,16 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
 	v.push_back(Setting(Setting::RULE, 0, font_ascender(_finfo, xform)));
 	return 1;
 
-      case U_VISIBLESPACE:
-	v.push_back(Setting(Setting::MOVE, 50, -150));
-	v.push_back(Setting(Setting::RULE, 40, 150));
-	v.push_back(Setting(Setting::RULE, _spacewidth, 40));
-	v.push_back(Setting(Setting::RULE, 40, 150));
-	v.push_back(Setting(Setting::MOVE, 50, 150));
+    case U_VISIBLESPACE: {
+        int sb = (int) (0.050 * _units_per_em), h = (int) (0.150 * _units_per_em),
+            lw = (int) (0.040 * _units_per_em);
+	v.push_back(Setting(Setting::MOVE, sb, -h));
+	v.push_back(Setting(Setting::RULE, lw, h));
+	v.push_back(Setting(Setting::RULE, _spacewidth, lw));
+	v.push_back(Setting(Setting::RULE, lw, h));
+	v.push_back(Setting(Setting::MOVE, sb, h));
 	return 2;
+    }
 
       case U_SS:
 	if (char_setting(v, metrics, 'S', 'S', 0))
@@ -565,12 +596,12 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
 	break;
 
       case U_ASTERISKMATH: {
-	  int bounds[5];
+	  double bounds[5];
 	  double dropdown = 0;
 	  if (char_bounds(bounds, bounds[4], _finfo, xform, '*'))
-	      dropdown += std::max(bounds[3], 0) + std::min(bounds[1], 0);
+	      dropdown += std::max(bounds[3], 0.) + std::min(bounds[1], 0.);
 	  if (char_bounds(bounds, bounds[4], _finfo, xform, '('))
-	      dropdown -= std::max(bounds[3], 0) + std::min(bounds[1], 0);
+	      dropdown -= std::max(bounds[3], 0.) + std::min(bounds[1], 0.);
 	  v.push_back(Setting(Setting::MOVE, 0, (int) (-dropdown / 2)));
 	  if (char_setting(v, metrics, '*', 0)) {
 	      v.push_back(Setting(Setting::MOVE, 0, -(int) (-dropdown / 2)));
@@ -583,7 +614,7 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
 	if (char_setting(v, metrics, U_ENDASH, 0)) {
 	    if (!_finfo.is_fixed_pitch()) {
 		double d = char_one_bound(_finfo, xform, 4, true, 0, U_ENDASH, 0);
-		v.push_back(Setting(Setting::MOVE, (int) (667 - 2 * d - letterspace), 0));
+		v.push_back(Setting(Setting::MOVE, (int) (_units_per_em * 0.667 - 2 * d - letterspace), 0));
 	    }
 	    char_setting(v, metrics, U_ENDASH, 0);
 	    return 1;
@@ -594,7 +625,7 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
 	if (char_setting(v, metrics, U_ENDASH, 0)) {
 	    if (!_finfo.is_fixed_pitch()) {
 		double d = char_one_bound(_finfo, xform, 4, true, 0, U_ENDASH, 0);
-		v.push_back(Setting(Setting::MOVE, (int) (750 - 2 * d - letterspace), 0));
+		v.push_back(Setting(Setting::MOVE, (int) (_units_per_em * 0.750 - 2 * d - letterspace), 0));
 	    }
 	    char_setting(v, metrics, U_ENDASH, 0);
 	    return 1;
@@ -610,7 +641,8 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
       case U_INTERROBANG: {
 	  double exclam_offset =
 	      (char_one_bound(_finfo, xform, 4, true, 0, '?', 0)
-	       - char_one_bound(_finfo, xform, 4, true, 0, '!', 0)) * 0.5 + 50;
+	       - char_one_bound(_finfo, xform, 4, true, 0, '!', 0)) * 0.5
+              + 0.050 * _units_per_em;
 	  v.push_back(Setting(Setting::PUSH));
 	  v.push_back(Setting(Setting::MOVE, (int) exclam_offset, 0));
 	  if (char_setting(v, metrics, '!', 0)) {
@@ -624,7 +656,8 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
       case U_INTERROBANGDOWN: {
 	  double exclam_offset =
 	      (char_one_bound(_finfo, xform, 4, true, 0, U_QUESTIONDOWN, 0)
-	       - char_one_bound(_finfo, xform, 4, true, 0, U_EXCLAMDOWN, 0)) * 0.5 + 50;
+	       - char_one_bound(_finfo, xform, 4, true, 0, U_EXCLAMDOWN, 0)) * 0.5
+              + 0.050 * _units_per_em;
 	  v.push_back(Setting(Setting::PUSH));
 	  v.push_back(Setting(Setting::MOVE, (int) exclam_offset, 0));
 	  if (char_setting(v, metrics, U_EXCLAMDOWN, 0)) {
@@ -675,7 +708,7 @@ T1Secondary::setting(uint32_t uni, Vector<Setting> &v, Metrics &metrics, ErrorHa
 
 
 bool
-char_bounds(int bounds[4], int &width, const FontInfo &finfo,
+char_bounds(double bounds[4], double& width, const FontInfo &finfo,
 	    const Transform &transform, uint32_t uni)
 {
     if (Efont::OpenType::Glyph g = finfo.cmap->map_uni(uni))
@@ -684,37 +717,24 @@ char_bounds(int bounds[4], int &width, const FontInfo &finfo,
 	return false;
 }
 
-int
+double
 char_one_bound(const FontInfo &finfo, const Transform &transform,
-	       int dimen, bool max, int best, uint32_t uni, ...)
+	       int dimen, bool max, double best, int uni, ...)
 {
-    int bounds[5];
+    double bounds[5];
     va_list val;
     va_start(val, uni);
     while (uni != 0) {
 	if (char_bounds(bounds, bounds[4], finfo, transform, uni))
 	    if (max ? bounds[dimen] > best : bounds[dimen] < best)
 		best = bounds[dimen];
-	uni = va_arg(val, uint32_t);
+	uni = va_arg(val, int);
     }
     va_end(val);
     return best;
 }
 
-int
-font_x_height(const FontInfo &finfo, const Transform &font_xform)
-{
-    try {
-	Efont::OpenType::Os2 os2(finfo.otf->table("OS/2"));
-	return os2.x_height();
-    } catch (Efont::OpenType::Bounds) {
-	// XXX what if 'x', 'm', 'z' were subject to substitution?
-	return char_one_bound(finfo, font_xform, 3, false, finfo.units_per_em(),
-			      'x', 'm', 'z', 0);
-    }
-}
-
-int
+double
 font_cap_height(const FontInfo &finfo, const Transform &font_xform)
 {
     try {
@@ -723,11 +743,11 @@ font_cap_height(const FontInfo &finfo, const Transform &font_xform)
     } catch (Efont::OpenType::Bounds) {
 	// XXX what if 'H', 'O', 'B' were subject to substitution?
 	return char_one_bound(finfo, font_xform, 3, false, finfo.units_per_em(),
-			      'H', 'O', 'B', 0);
+			      (int) 'H', (int) 'O', (int) 'B', 0);
     }
 }
 
-int
+double
 font_ascender(const FontInfo &finfo, const Transform &font_xform)
 {
     try {
@@ -736,7 +756,7 @@ font_ascender(const FontInfo &finfo, const Transform &font_xform)
     } catch (Efont::OpenType::Bounds) {
 	// XXX what if 'd', 'l' were subject to substitution?
 	return char_one_bound(finfo, font_xform, 3, true,
-			      font_x_height(finfo, font_xform),
-			      'd', 'l', 0);
+			      finfo.x_height(font_xform),
+			      (int) 'd', (int) 'l', 0);
     }
 }
