@@ -179,10 +179,12 @@ strip_newlines(const String &str)
 static void
 write_char(FILE *outf, int c, PermString n, Type1Charstring *g, const Transform &font_transform, Type1Font *font)
 {
-    int bb[4], wx;
+    double bb[4], wx;
     CharstringBounds::bounds(font_transform, CharstringContext(font, g), bb, wx);
     fprintf(outf, "C %d ; WX %d ; N %s ; B %d %d %d %d ;\n",
-	    c, wx, n.c_str(), bb[0], bb[1], bb[2], bb[3]);
+	    c, (int) ceil(wx), n.c_str(),
+            (int) floor(bb[0]), (int) floor(bb[1]),
+            (int) ceil(bb[2]), (int) ceil(bb[3]));
 }
 
 static void
@@ -211,26 +213,26 @@ Comment Generated by t1rawafm\n");
 	font_transform.scale(1000);
     }
 
-    int bb[4], wx;
+    double bb[4], wx;
     if (Type1Charstring *t1cs = font->glyph("H")) {
 	CharstringBounds::bounds(font_transform, CharstringContext(font, t1cs), bb, wx);
 	if (bb[3])
-	    fprintf(outf, "Ascender %d\n", bb[3]);
+	    fprintf(outf, "CapHeight %d\n", (int) ceil(bb[3]));
     }
     if (Type1Charstring *t1cs = font->glyph("x")) {
 	CharstringBounds::bounds(font_transform, CharstringContext(font, t1cs), bb, wx);
 	if (bb[3])
-	    fprintf(outf, "XHeight %d\n", bb[3]);
+	    fprintf(outf, "XHeight %d\n", (int) ceil(bb[3]));
     }
     if (Type1Charstring *t1cs = font->glyph("d")) {
 	CharstringBounds::bounds(font_transform, CharstringContext(font, t1cs), bb, wx);
 	if (bb[3])
-	    fprintf(outf, "Ascender %d\n", bb[3]);
+	    fprintf(outf, "Ascender %d\n", (int) ceil(bb[3]));
     }
     if (Type1Charstring *t1cs = font->glyph("p")) {
 	CharstringBounds::bounds(font_transform, CharstringContext(font, t1cs), bb, wx);
-	if (bb[3])
-	    fprintf(outf, "Descender %d\n", bb[1]);
+	if (bb[1])
+	    fprintf(outf, "Descender %d\n", (int) floor(bb[1]));
     }
 
     Vector<double> vd;
@@ -241,7 +243,7 @@ Comment Generated by t1rawafm\n");
 	if (t1d->value_numvec(vd) && vd.size() > 0)
 	    fprintf(outf, "StdVW %d\n", (int) ceil(vd[0]));
 
-    int fontbb[4] = { 1000000, 1000000, -1000000, -1000000 };
+    double fontbb[4] = { 1000000, 1000000, -1000000, -1000000 };
     for (int i = 0; i < font->nglyphs(); ++i) {
 	CharstringBounds::bounds(font_transform, CharstringContext(font, font->glyph(i)), bb, wx);
 	fontbb[0] = std::min(fontbb[0], bb[0]);
@@ -249,7 +251,9 @@ Comment Generated by t1rawafm\n");
 	fontbb[2] = std::max(fontbb[2], bb[2]);
 	fontbb[3] = std::max(fontbb[3], bb[3]);
     }
-    fprintf(outf, "FontBBox %d %d %d %d\n", fontbb[0], fontbb[1], fontbb[2], fontbb[3]);
+    fprintf(outf, "FontBBox %d %d %d %d\n",
+            (int) floor(fontbb[0]), (int) floor(fontbb[1]),
+            (int) ceil(fontbb[2]), (int) ceil(fontbb[3]));
 
     fprintf(outf, "FontName %s\n", font->font_name().c_str());
 
