@@ -6,6 +6,8 @@
  *   Copyright 1997-1999, 2000, 2002 by
  *     Frederic Loyer <loyer@ensta.fr>
  *     Werner Lemberg <wl@gnu.org>.
+ *   Copyright 2009-2013 by
+ *     Peter Breitenlohner <tex-live@tug.org>
  */
 
 /*
@@ -19,6 +21,10 @@
  *   Adapted from afm2tfm by F. Loyer <loyer@ensta.fr>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>         /* for size_t */
@@ -42,7 +48,7 @@
 #include "subfont.h"
 
 
-char ident[] = "ttf2tfm version 1.5";
+char ident[] = "ttf2tfm version 2.0";
 const char *progname = "ttf2tfm";            /* for error/warning messages */
 
 /* command line options */
@@ -235,8 +241,40 @@ end:
 }
 
 
+#define MAX_SFLIST 10
+static void
+add_subfont_list(Font *fnt)
+{
+  if (fnt->subfont_list == NULL)
+    fnt->subfont_list = (sflist *)mymalloc(MAX_SFLIST * sizeof(sflist));
+  else if (fnt->subfont_num % MAX_SFLIST == 0)
+    fnt->subfont_list = (sflist *)myrealloc(fnt->subfont_list,
+      (fnt->subfont_num / MAX_SFLIST + 1) * MAX_SFLIST * sizeof(sflist));
+
+  (fnt->subfont_list[fnt->subfont_num]).name =
+      (char *)mymalloc(strlen(fnt->fullname)+1);
+  strcpy((fnt->subfont_list[fnt->subfont_num]).name, fnt->fullname);
+  (fnt->subfont_list[fnt->subfont_num]).cksum = fnt->cksum;
+
+  fnt->subfont_num++;
+}
+
+
+static void
+release_subfont_list(Font *fnt)
+{
+  register int i;
+
+  for (i = 0; i < fnt->subfont_num; i++)
+    free((fnt->subfont_list[i]).name);
+
+  free(fnt->subfont_list);
+}
+
+
 #define VERSION "\
 Copyright (C) 1997-1999, 2000, 2002 Frederic Loyer and Werner Lemberg.\n\
+              2009-2013 Peter Breitenlohner\n\
 There is NO warranty.  You may redistribute this software\n\
 under the terms of the GNU General Public License\n\
 and the Dvips copyright.\n\
@@ -272,6 +310,7 @@ version(void)
 -L LIGFILE[.sfd]    create 1st/2nd byte ligatures in subfonts using LIGFILE\n\
 -n                  use PS names of TrueType font\n\
 -N                  use only PS names and no cmap\n\
+-o FILE[.ovp]       make an OVP file for conversion to OVF and OFM\n\
 -O                  use octal for all character codes in the vpl file\n\
 -p ENCFILE[.enc]    read ENCFILE for the TTF->raw TeX mapping\n\
 -P INT              select INT as the TTF platform ID [3]\n\
@@ -325,16 +364,10 @@ handle_options(int argc, char *argv[], Font *fnt)
   if (!quiet)
     printf("This is %s\n", ident);
 
-#if defined(MSDOS) || defined(OS2) || defined(ATARIST)
   /* Make VPL file identical to that created under Unix */
   fnt->titlebuf = (char *)mymalloc(strlen(progname) + strlen(argv[1]) +
                                    1 + 1);
   sprintf(fnt->titlebuf, "%s %s", progname, argv[1]);
-#else
-  fnt->titlebuf = (char *)mymalloc(strlen(argv[0]) + strlen(argv[1]) +
-                                   1 + 1);
-  sprintf(fnt->titlebuf, "%s %s", argv[0], argv[1]);
-#endif
 
 
   /*
@@ -528,6 +561,15 @@ handle_options(int argc, char *argv[], Font *fnt)
       arginc = 1;
       break;
 
+    case 'o':
+      if (argc <= 3)
+        oops("Missing parameter for -o option.");
+      if (vpl_name)
+        free(vpl_name);
+      vpl_name = newstring(argv[3]);
+      handle_extension(&vpl_name, ".ovp");
+      break;
+
     default:
       if (argc <= 3 || argv[3][0] == '-')
       {
@@ -664,6 +706,9 @@ handle_options(int argc, char *argv[], Font *fnt)
       warning("Ignoring `-v' and `-V' switches for subfonts.");
       makevpl = 0;
     }
+    if (vpl_name)
+      if ((fnt->vplout = fopen(vpl_name, "wb")) == NULL)
+        oops("Cannot open ovp output file.");
     if (have_capheight)
       warning("Ignoring `-c' switch for subfonts.");
     if (fnt->inencname || fnt->outencname)
@@ -688,7 +733,7 @@ handle_options(int argc, char *argv[], Font *fnt)
       oops("Bad small caps height.");
 
     if (vpl_name)
-      if ((fnt->vplout = fopen(vpl_name, "wt")) == NULL)
+      if ((fnt->vplout = fopen(vpl_name, "wb")) == NULL)
         oops("Cannot open vpl output file.");
   
     if (fnt->subfont_ligs)
@@ -864,6 +909,18 @@ main(int argc, char *argv[])
       if (font.replacements)
         warning("Replacement glyphs will be ignored.");
 
+      /* second try to get an xheight value */
+      if (font.xheight == 0)
+      {
+        if (NULL != (ti = findadobe("x", font.charlist)))
+          font.xheight = ti->ury;
+        else if (font.pid == 3 && font.eid == 1 &&
+                 NULL != (ti = findadobe(".c0x78", font.charlist)))
+          font.xheight = ti->ury;
+        else
+          font.xheight = 400;
+      }
+
       if (NULL != (ti = findadobe("space", font.charlist)))
         font.fontspace = ti->width;
       else if (NULL != (ti = findadobe(".c0x20", font.charlist)))
@@ -879,10 +936,19 @@ main(int argc, char *argv[])
         writetfm(&font);
         if (font.write_enc)
           writeenc(&font);
+        if (font.vplout)
+          add_subfont_list(&font);
       }
     }
 
     close_sfd();
+
+    if (font.vplout)
+    {
+      writeovp(&font);
+      fclose(font.vplout);
+      release_subfont_list(&font);
+    }
   }
   else
   {
@@ -891,6 +957,18 @@ main(int argc, char *argv[])
     readttf(&font, quiet, False);
     replace_glyphs(&font);
 
+    /* second try to get an xheight value */
+    if (font.xheight == 0)
+    {
+      if (NULL != (ti = findadobe("x", font.charlist)))
+        font.xheight = ti->ury;
+      else if (font.pid == 3 && font.eid == 1 &&
+               NULL != (ti = findadobe(".c0x78", font.charlist)))
+        font.xheight = ti->ury;
+      else
+        font.xheight = 400;
+    }
+
     if (NULL != (ti = findadobe("space", font.charlist)))
       font.fontspace = ti->width;
     else if (NULL != (ti = findadobe(".c0x20", font.charlist)))
