@@ -17,9 +17,6 @@
    You should have received a copy of the GNU General Public License along
    with LuaTeX; if not, see <http://www.gnu.org/licenses/>. */
 
-static const char _svn_version[] =
-    "$Id: limglib.c 4847 2014-03-05 18:13:17Z luigi $ "
-    "$URL: https://foundry.supelec.fr/svn/luatex/trunk/source/texk/web2c/luatexdir/lua/limglib.c $";
 
 #include "ptexlib.h"
 #include "lua/luatex-api.h"
