@@ -742,7 +742,9 @@ read_pdf_info(char *image_name, char *page_name, int page_num,
             "PDF inclusion: found PDF version <%d.%d>, but at most version <1.%d> allowed";
         if (pdf_inclusion_errorlevel > 0) {
             pdftex_fail(msg, pdf_major_version_found, pdf_minor_version_found, minor_pdf_version_wanted);
-        } else {
+        } else if (pdf_inclusion_errorlevel < 0) {
+            ; /* do nothing */
+        } else { /* = 0, give warning */
             pdftex_warn(msg, pdf_major_version_found, pdf_minor_version_found, minor_pdf_version_wanted);
         }
     }
@@ -754,7 +756,9 @@ read_pdf_info(char *image_name, char *page_name, int page_num,
             "PDF inclusion: found PDF version <%.1f>, but at most version <%.1f> allowed";
         if (pdf_inclusion_errorlevel > 0) {
             pdftex_fail(msg, pdf_version_found, pdf_version_wanted);
-        } else {
+        } else if (pdf_inclusion_errorlevel < 0) {
+            ; /* do nothing */
+        } else { /* = 0, give warning */
             pdftex_warn(msg, pdf_version_found, pdf_version_wanted);
         }
     }
