@@ -1,5 +1,5 @@
 /*
-Copyright 1996-2011 Han The Thanh <thanh@pdftex.org>
+Copyright 1996-2014 Han The Thanh <thanh@pdftex.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -379,7 +379,7 @@ static float t1_scan_num(char *p, char **r)
         pdftex_fail("a number expected: `%s'", t1_line_array);
     }
     if (r != NULL) {
-        for (; isdigit(*p) || *p == '.' ||
+        for (; isdigit((unsigned char)*p) || *p == '.' ||
              *p == 'e' || *p == 'E' || *p == '+' || *p == '-'; p++);
         *r = p;
     }
@@ -1312,7 +1312,9 @@ static void t1_subset_ascii_part(void)
     t1_getline();
     while (!t1_prefix("/Encoding")) {
         t1_scan_param();
-        t1_putline();
+        if (!(t1_prefix("/UniqueID")
+              && !strncmp(t1_line_array + strlen(t1_line_array) -4, "def", 3)))
+            t1_putline();
         t1_getline();
     }
     glyph_names = t1_builtin_enc();
@@ -1491,7 +1493,7 @@ static void t1_flush_cs(boolean is_subr)
     t1_line_ptr = t1_line_array;
     for (p = start_line; p - start_line < size_pos;)
         *t1_line_ptr++ = *p++;
-    while (isdigit(*p))
+    while (isdigit((unsigned char)*p))
         p++;
     sprintf(t1_line_ptr, "%u", count);
     strcat(t1_line_ptr, p);
