@@ -24,8 +24,8 @@
   SU: Adapted from non-k xdvi's popups.c and added saving functionality.
 */
 
-#include <string.h>
 #include "xdvi-config.h"
+#include <string.h>
 #include "xdvi.h"
 #include "my-vsnprintf.h"
 #include <ctype.h>
@@ -261,7 +261,7 @@ cb_select_format(Widget w, XtPointer client_data, XtPointer call_data)
     struct save_or_print_info *info = NULL;
     Widget file_text;
     char *filename;
-    int i = 0;
+    ptrdiff_t i;
 
 #ifndef MOTIF
     Widget button;
@@ -272,7 +272,7 @@ cb_select_format(Widget w, XtPointer client_data, XtPointer call_data)
     UNUSED(call_data);
 
 #ifdef MOTIF
-    i = (int)client_data;
+    i = (ptrdiff_t) client_data;
     XtVaGetValues(XtParent(w), XmNuserData, &info, NULL);
     ASSERT(info != NULL, "Expected struct save_or_print_info * in XmNuserData of button!");
     
@@ -286,7 +286,8 @@ cb_select_format(Widget w, XtPointer client_data, XtPointer call_data)
     }
 #else /* MOTIF */
     info = (struct save_or_print_info *)client_data;
-    
+
+    i = 0;
     if (get_widget_by_name(&file_text, info->shell, Xdvi_TO_FILE_TEXT, True)
 	&& get_widget_by_name(&button, info->shell, Xdvi_FORMAT_SELECTION_BUTTON_NAME, True)) {
 
@@ -1182,10 +1183,8 @@ xaw_create_dialog(struct save_or_print_info *info)
     Widget form, paned, box;
     Widget dummy_label_form, dummy_pages_form; /* dummy forms to get indentation consistent */
     Widget save_to_file_form;
-    Widget dest_label;
     Widget print_to_printer_form, print_to_file_form, dvips_options_form;
     Widget dvips_options_label;
-    Widget range_label;
     Widget page_range_form;
     Widget range_marked_form;
     Widget range_from_to_form;
@@ -1259,7 +1258,7 @@ xaw_create_dialog(struct save_or_print_info *info)
 						   XtNborderWidth, 0,
 						   HORIZONTAL_RESIZING_YES,
 						   NULL);
-	dest_label = XtVaCreateManagedWidget("print_to", labelWidgetClass, dummy_label_form,
+	             XtVaCreateManagedWidget("print_to", labelWidgetClass, dummy_label_form,
 					     XtNlabel, "Print to: ",
 					     XtNborderWidth, 0,
 					     HORIZONTAL_RESIZING_NO,
@@ -1365,7 +1364,7 @@ xaw_create_dialog(struct save_or_print_info *info)
 						   XtNborderWidth, 0,
 						   HORIZONTAL_RESIZING_YES,
 						   NULL);
-	dest_label = XtVaCreateManagedWidget("save_as", labelWidgetClass, dummy_label_form,
+	             XtVaCreateManagedWidget("save_as", labelWidgetClass, dummy_label_form,
 					     XtNlabel, "Save as: ",
 					     XtNborderWidth, 0,
 					     HORIZONTAL_RESIZING_NO,
@@ -1552,7 +1551,7 @@ xaw_create_dialog(struct save_or_print_info *info)
 					       HORIZONTAL_RESIZING_NO,
 					       NULL);
 
-    range_label = XtVaCreateManagedWidget("range_lab", labelWidgetClass, dummy_pages_form,
+                  XtVaCreateManagedWidget("range_lab", labelWidgetClass, dummy_pages_form,
 					  XtNlabel, "Pages:",
 					  XtNborderWidth, 0,
 					  HORIZONTAL_RESIZING_NO,
